{% extends 'django_dzenlog/base.html' %}
{% load i18n dzenlog_tags %}

{% block content %}
    <div class="b-tag-cloud">
    {% for tag in object_list %}
        <a class="fs-{{tag.font_size}}" href="{% call bytag_url tag.name %}">{{tag.name}}</a>
    {% endfor %}
    </div>
{% endblock %}

